.. _ansible_tower:

Ansible Tower
=============

`Ansible Tower <https://ansible.com/tower>`_ (formerly 'AWX') is a web-based solution that makes Ansible even more easy to use for IT teams of all kinds.  It's designed to be the hub for all of your automation tasks.

Tower allows you to control access to who can access what, even allowing sharing of SSH credentials without someone being able to transfer those credentials.  Inventory can be graphically managed or synced with a wide variety of cloud sources.  It logs all of your jobs, integrates well with LDAP, and has an amazing browsable REST API.  Command line tools are available for easy integration with Jenkins as well.  Provisioning callbacks provide great support for autoscaling topologies.

Find out more about Tower features and how to download it on the `Ansible Tower webpage <https://ansible.com/tower>`_.  Tower
is free for usage for up to 10 nodes, and comes bundled with amazing support from Ansible, Inc.  As you would expect, Tower is
installed using Ansible playbooks!
